#include <assert.h>
#include "wmsdk_config.h"
#include "wm_types.h"
#include <time.h>

#include "freertos/FreeRTOS.h"
#include "freertos/queue.h"
#include <freertos/timers.h>
#include "wm_event.h"
#include "wm_task_config.h"
#include "wm_nm_api.h"
#include "lwip/apps/wm_sntp.h"
#include "lwip/netdb.h"
#include "wm_drv_rtc.h"
#include "ui/ui.h"

#define LOG_TAG "example"
#include "wm_log.h"

#ifndef CONFIG_EXAMPLE_WIFI_SSID
#define CONFIG_EXAMPLE_WIFI_SSID "w600"
#endif

#ifndef CONFIG_EXAMPLE_WIFI_PASSWORD
#define CONFIG_EXAMPLE_WIFI_PASSWORD "12345678"
#endif

#define WM_SNTP_SYNC_TIMEOUT_TICK (5000)
#define WM_SNTP_SERVER_NAME_1     "ntp.ntsc.ac.cn"
#define WM_SNTP_SERVER_NAME_2     "ntp1.aliyun.com"

static wm_device_t *rtc_dev = NULL;

static TimerHandle_t timer1sec  = NULL;

static struct tm *tm;

static char buffer[64];

static void wm_sntp_from_default_server(void)
{
    for (int i = 0; i < CONFIG_LWIP_MAX_NTP_SERVERS; i++) {
        const char *server = wm_sntp_getservername(i);
        if (server != NULL) {
            wm_log_info("default %dst sntp server: %s", i, server);
        }
    }

    setenv("TZ", "UTC+8", 1);
    tm = wm_get_time_sync(WM_SNTP_SYNC_TIMEOUT_TICK);
    if (tm == NULL) {
        wm_log_error("get NTP failed");
    } else {
        rtc_dev = wm_dt_get_device_by_name("rtc");

        if (wm_drv_rtc_set_time(rtc_dev, tm) != WM_ERR_SUCCESS) {
            wm_log_info("set time failed");
        }
    }
}

static void timer_1sec_callback(TimerHandle_t xTimer) {
    if (wm_drv_rtc_get_time(rtc_dev, tm) == WM_ERR_SUCCESS) {
        // AM, PM 
        strftime(buffer, sizeof(buffer), "%p", tm);
        lv_label_set_text(ui_LabelAmPm, buffer);
        // 以补零后的十进制数表示的小时（12 小时制）
        strftime(buffer, sizeof(buffer), "%I:%M", tm);
        lv_label_set_text(ui_LabelTime, buffer);
        // 补零后，以十进制数显示的秒
        strftime(buffer, sizeof(buffer), "%S", tm);
        lv_label_set_text(ui_LabelSec, buffer);
        // wm_log_info("now is: %s", buffer);
    }
}

int user_clock(void)
{
    int count                    = 0;
    wm_nm_wifi_station_cfg_t cfg = { CONFIG_EXAMPLE_WIFI_SSID, CONFIG_EXAMPLE_WIFI_PASSWORD };

    if (wm_nm_start_wifi_station(&cfg) != WM_ERR_SUCCESS) {
        wm_log_error("wifi station start failed");
        return WM_ERR_FAILED;
    }

    while (wm_nm_get_wifi_station_state() != WM_NM_WIFI_STA_GOT_IP) {
        vTaskDelay(pdMS_TO_TICKS(1000));
        ++count;
        if (count % 5 == 0) {
            wm_log_info("waiting for connect to %s", CONFIG_EXAMPLE_WIFI_SSID);
        }
    }

    wm_log_info("start sntp demo");

    wm_sntp_start();

    /** start sntp by default config */
    wm_sntp_from_default_server();

    wm_log_info("finish sntp");
    wm_sntp_stop();

    // 创建10ms定时器，往任务发送消息。
    timer1sec = xTimerCreate("1s", pdMS_TO_TICKS(1000), pdTRUE, NULL, timer_1sec_callback);
    if(timer1sec == NULL){
        printf("---> xTimerCreate err!");
        return WM_ERR_FAILED;
    }
    xTimerStart(timer1sec, 0); 
    return WM_ERR_SUCCESS;
}
